Module write

Module write 

Request and client builders for the Write client.

Structs

Append
A request builder for appending rows to the default stream.
AppendWithOffset
A request builder for appending rows to an application-created stream, with an optional stream offset to ensure exactly-once semantics.
ClientBuilder
A builder for Write.
WriterBuilder
A builder to create a stream writer.