pub struct Append { /* private fields */ }Expand description
A request builder for appending rows on the default stream.
Implementations
Sourceimpl Append
impl Append
Sourcepub fn send(self) -> AppendFuture ⓘ
pub fn send(self) -> AppendFuture ⓘ
Append rows to the stream.
Applications are encouraged to queue up requests and await their responses independently.
Example
let f1 = writer.append(rows()).send();
let f2 = writer.append(rows()).send();
let resp1 = f1.await?;
let resp2 = f2.await?;
use google_cloud_bigquery::model::ArrowRecordBatch;
fn rows() -> ArrowRecordBatch {
todo!("Define your rows...")
}Trait Implementations