RangeElement

Trait RangeElement 

pub trait RangeElement: FromSql + RangeElement { }
A marker trait for types that can be elements of a BigQuery Range.

BigQuery RANGE<T> values support Date, DateTime, and Timestamp element types.

This trait is sealed and cannot be implemented for types outside of this crate.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl RangeElement for Date

Source

impl RangeElement for DateTime

Source

impl RangeElement for Timestamp

Implementors