Module error

Module error 

Custom errors for the BigQuery clients.

Enums

AppendError
Represents an error that can occur when appending rows.
CommitError
Represents an error that can occur when committing a pending write stream.
ConvertError
Represents failures when converting a BigQuery cell value to a Rust type.
QueryError
Errors that can occur during query configuration, execution, or polling.
RowError
Errors that can occur when retrieving value cells from a Row or iterating over query results.
WriterBuilderError
Represents an error that can occur when building a writer.