#[non_exhaustive]pub enum AttachError {
TypeMismatch {
expected: Type,
actual: Type,
},
#[non_exhaustive] Rpc {
source: Error,
},
}Expand description
Represents an error that can occur when attaching to an existing stream.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TypeMismatch
The stream type provided by the service did not match the expected type.
Fields

expected: TypeThe expected stream type.

actual: TypeThe actual stream type returned by the service.
#[non_exhaustive]Rpc
The underlying RPC failed.