#[non_exhaustive]pub enum RowError {
ColumnNotFound(String),
IndexOutOfRange {
index: usize,
len: usize,
},
TypeConversion {
column: String,
source: ConvertError,
},
InvalidRowFormat(String),
#[non_exhaustive] Rpc {
source: Error,
},
}Expand description
Errors that can occur when retrieving value cells from a Row or iterating over query results.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ColumnNotFound(String)
The requested column name or index was not found in the row.
IndexOutOfRange
The requested column index was out of range.
TypeConversion
Failed to convert/parse the cell value to the target type.
Fields

source: ConvertErrorThe underlying parsing error.
InvalidRowFormat(String)
The JSON format returned by the service did not match expectations.
#[non_exhaustive]Rpc
The underlying RPC failed.