#[non_exhaustive]pub enum WriterBuilderError {
#[non_exhaustive] TypeMismatch {
expected: String,
actual: String,
},
#[non_exhaustive] Rpc {
source: Error,
},
}Expand description
Represents an error that can occur when building a writer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
#[non_exhaustive]TypeMismatch
The targeted write stream was a different stream type than expected.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
#[non_exhaustive]Rpc
The underlying RPC failed.