The messages and enums that are part of this client library.
Modules
- append_
rows_ request - Defines additional types related to AppendRowsRequest.
- append_
rows_ response - Defines additional types related to AppendRowsResponse.
- arrow_
serialization_ options - Defines additional types related to ArrowSerializationOptions.
- avro_
serialization_ options - Defines additional types related to AvroSerializationOptions.
- client_
stats - Defines additional types related to ClientStats.
- read_
rows_ request - Defines additional types related to ReadRowsRequest.
- read_
rows_ response - Defines additional types related to ReadRowsResponse.
- read_
session - Defines additional types related to ReadSession.
- row_
error - Defines additional types related to RowError.
- storage_
error - Defines additional types related to StorageError.
- stream_
stats - Defines additional types related to StreamStats.
- table_
field_ schema - Defines additional types related to TableFieldSchema.
- write_
stream - Defines additional types related to WriteStream.
Structs
- Append
Rows Request - Request message for
AppendRows. - Append
Rows Response - Response message for
AppendRows. - Arrow
Record Batch - Arrow RecordBatch.
- Arrow
Schema - Arrow schema as specified in https://arrow.apache.org/docs/python/api/datatypes.html and serialized to bytes using IPC: https://arrow.apache.org/docs/format/Columnar.html#serialization-and-interprocess-communication-ipc
- Arrow
Serialization Options - Contains options specific to Arrow Serialization.
- Avro
Rows - Avro rows.
- Avro
Schema - Avro schema.
- Avro
Serialization Options - Contains options specific to Avro Serialization.
- Batch
Commit Write Streams Request - Request message for
BatchCommitWriteStreams. - Batch
Commit Write Streams Response - Response message for
BatchCommitWriteStreams. - Client
Stats - Stats and telemetry data gathered on the client side about requests being sent to the BigQuery Storage service, for internal use only.
- Create
Read Session Request - Request message for
CreateReadSession. - Create
Write Stream Request - Request message for
CreateWriteStream. - Finalize
Write Stream Request - Request message for invoking
FinalizeWriteStream. - Finalize
Write Stream Response - Response message for
FinalizeWriteStream. - Flush
Rows Request - Request message for
FlushRows. - Flush
Rows Response - Respond message for
FlushRows. - GetWrite
Stream Request - Request message for
GetWriteStreamRequest. - Proto
Rows - Proto
Schema - ProtoSchema describes the schema of the serialized protocol buffer data rows.
- Read
Rows Request - Request message for
ReadRows. - Read
Rows Response - Response from calling
ReadRowsmay include row data, progress and throttling information. - Read
Session - Information about the ReadSession.
- Read
Stream - Information about a single stream that gets data out of the storage system.
Most of the information about
ReadStreaminstances is aggregated, makingReadStreamlightweight. - RowError
- The message that presents row level error info in a request.
- Split
Read Stream Request - Request message for
SplitReadStream. - Split
Read Stream Response - Response message for
SplitReadStream. - Storage
Error - Structured custom BigQuery Storage error message. The error can be attached as error details in the returned rpc Status. In particular, the use of error codes allows more structured error handling, and reduces the need to evaluate unstructured error text strings.
- Stream
Stats - Estimated stream statistics for a given read Stream.
- Table
Field Schema - TableFieldSchema defines a single field/column within a table schema.
- Table
Schema - Schema of a table. This schema is a subset of google.cloud.bigquery.v2.TableSchema containing information necessary to generate valid message to write to BigQuery.
- Throttle
State - Information on if the current connection is being throttled.
- Write
Stream - Information about a single stream that gets data inside the storage system.
Enums
- Data
Format - Data format for input or output data.
- Write
Stream View - WriteStreamView is a view enum that controls what details about a write stream should be returned.