#[non_exhaustive]pub enum MissingValueInterpretation {
Unspecified,
NullValue,
DefaultValue,
UnknownValue(UnknownValue),
}Expand description
An enum to indicate how to interpret missing values of fields that are present in user schema but missing in rows. A missing value can represent a NULL or a column default value defined in BigQuery table schema.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Invalid missing value interpretation. Requests with this value will be rejected.
NullValue
Missing value is interpreted as NULL.
DefaultValue
Missing value is interpreted as column default value if declared in the table schema, NULL otherwise.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using MissingValueInterpretation::value or MissingValueInterpretation::name.
Implementations