#[non_exhaustive]pub enum Rows {
ProtoRows(Box<ProtoData>),
ArrowRows(Box<ArrowData>),
}Expand description
Input rows. The writer_schema field must be specified at the initial
request and currently, it will be ignored if specified in following
requests. Following requests must have data in the same format as the
initial request.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations