#[non_exhaustive]pub struct ProtoData {
pub writer_schema: Option<ProtoSchema>,
pub rows: Option<ProtoRows>,
/* private fields */
}Expand description
ProtoData contains the data rows and schema when constructing append requests.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.writer_schema: Option<ProtoSchema>Optional. The protocol buffer schema used to serialize the data. Provide this value whenever:
-
You send the first request of an RPC connection.
-
You change the input schema.
-
You specify a new destination table.
rows: Option<ProtoRows>Required. Serialized row data in protobuf message format. Currently, the backend expects the serialized rows to adhere to proto2 semantics when appending rows, particularly with respect to how default values are encoded.
Implementations
Sourceimpl ProtoData
impl ProtoData
Sourcepub fn set_writer_schema<T>(self, v: T) -> Selfwhere
T: Into<ProtoSchema>,
pub fn set_writer_schema<T>(self, v: T) -> Selfwhere
T: Into<ProtoSchema>,
Sets the value of writer_schema.
Example
ⓘ
use google_cloud_bigquery::model::ProtoSchema;
let x = ProtoData::new().set_writer_schema(ProtoSchema::default()/* use setters */);Sourcepub fn set_or_clear_writer_schema<T>(self, v: Option<T>) -> Selfwhere
T: Into<ProtoSchema>,
pub fn set_or_clear_writer_schema<T>(self, v: Option<T>) -> Selfwhere
T: Into<ProtoSchema>,
Sets or clears the value of writer_schema.
Example
ⓘ
use google_cloud_bigquery::model::ProtoSchema;
let x = ProtoData::new().set_or_clear_writer_schema(Some(ProtoSchema::default()/* use setters */));
let x = ProtoData::new().set_or_clear_writer_schema(None::<ProtoSchema>);Sourcepub fn set_or_clear_rows<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_rows<T>(self, v: Option<T>) -> Self