#[non_exhaustive]pub struct AppendResult {
pub offset: Option<Int64Value>,
/* private fields */
}Expand description
AppendResult is returned for successful append requests.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.offset: Option<Int64Value>The row offset at which the last append occurred. The offset will not be set if appending using default streams.
Implementations
Sourceimpl AppendResult
impl AppendResult
Sourcepub fn set_offset<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_offset<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sourcepub fn set_or_clear_offset<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_offset<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,