#[non_exhaustive]pub struct RequestStats {
pub send_time_millis: Option<i64>,
pub queued_requests_count: Option<i64>,
/* private fields */
}Expand description
Stats and telemetry data gathered on the client side about a single request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.send_time_millis: Option<i64>Optional. Timestamp indicating when the request was sent over the network, expressed in epoch milliseconds.
queued_requests_count: Option<i64>Optional. Number of pending requests at the moment this request was sent. This includes requests waiting to be sent, and those that are inflight.
Implementations
Sourceimpl RequestStats
impl RequestStats
Sourcepub fn set_send_time_millis<T>(self, v: T) -> Self
pub fn set_send_time_millis<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_send_time_millis<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_send_time_millis<T>(self, v: Option<T>) -> Self
Sets or clears the value of send_time_millis.
Example
ⓘ
let x = RequestStats::new().set_or_clear_send_time_millis(Some(42));
let x = RequestStats::new().set_or_clear_send_time_millis(None::<i32>);Sourcepub fn set_queued_requests_count<T>(self, v: T) -> Self
pub fn set_queued_requests_count<T>(self, v: T) -> Self
Sets the value of queued_requests_count.
Example
ⓘ
let x = RequestStats::new().set_queued_requests_count(42);Sourcepub fn set_or_clear_queued_requests_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_queued_requests_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of queued_requests_count.
Example
ⓘ
let x = RequestStats::new().set_or_clear_queued_requests_count(Some(42));
let x = RequestStats::new().set_or_clear_queued_requests_count(None::<i32>);Trait Implementations
Sourceimpl Clone for RequestStats
impl Clone for RequestStats
Sourceimpl Debug for RequestStats
impl Debug for RequestStats
Sourceimpl Default for RequestStats
impl Default for RequestStats
Sourceimpl Message for RequestStats
impl Message for RequestStats
Sourceimpl PartialEq for RequestStats
impl PartialEq for RequestStats
impl StructuralPartialEq for RequestStats