#[non_exhaustive]pub enum WriteStreamView {
Unspecified,
Basic,
Full,
UnknownValue(UnknownValue),
}Expand description
WriteStreamView is a view enum that controls what details about a write stream should be returned.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The default / unset value.
Basic
The BASIC projection returns basic metadata about a write stream. The basic view does not include schema information. This is the default view returned by GetWriteStream.
Full
The FULL projection returns all available write stream metadata, including the schema. CreateWriteStream returns the full projection of write stream metadata.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using WriteStreamView::value or WriteStreamView::name.
Implementations