Module read_rows_response

Module read_rows_response 

Defines additional types related to ReadRowsResponse.

Enums

Rows
Row data is returned in format specified during session creation.
Schema
The schema for the read. If read_options.selected_fields is set, the schema may be different from the table schema as it will only contain the selected fields. This schema is equivalent to the one returned by CreateSession. This field is only populated in the first ReadRowsResponse RPC.