Module read_session

Module read_session 

Defines additional types related to ReadSession.

Modules

table_read_options
Defines additional types related to TableReadOptions.

Structs

TableModifiers
Additional attributes when reading a table.
TableReadOptions
Options dictating how we read a table.

Enums

Schema
The schema for the read. If read_options.selected_fields is set, the schema may be different from the table schema as it will only contain the selected fields.