#[non_exhaustive]pub enum Schema {
AvroSchema(Box<AvroSchema>),
ArrowSchema(Box<ArrowSchema>),
}Expand description
The schema for the read. If read_options.selected_fields is set, the schema may be different from the table schema as it will only contain the selected fields.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AvroSchema(Box<AvroSchema>)
Output only. Avro schema.
ArrowSchema(Box<ArrowSchema>)
Output only. Arrow schema.
Implementations
Sourceimpl Schema
impl Schema
Sourcepub fn from_avro_schema(value: impl Into<Box<AvroSchema>>) -> Self
pub fn from_avro_schema(value: impl Into<Box<AvroSchema>>) -> Self
Initializes the enum to the AvroSchema branch.
Sourcepub fn from_arrow_schema(value: impl Into<Box<ArrowSchema>>) -> Self
pub fn from_arrow_schema(value: impl Into<Box<ArrowSchema>>) -> Self
Initializes the enum to the ArrowSchema branch.