Module table_read_options

Module table_read_options 

Defines additional types related to TableReadOptions.

Enums

OutputFormatSerializationOptions
ResponseCompressionCodec
Specifies which compression codec to attempt on the entire serialized response payload (either Arrow record batch or Avro rows). This is not to be confused with the Apache Arrow native compression codecs specified in ArrowSerializationOptions. For performance reasons, when creating a read session requesting Arrow responses, setting both native Arrow compression and application-level response compression will not be allowed - choose, at most, one kind of compression.