#[non_exhaustive]pub enum StorageErrorCode {
Show 16 variants
Unspecified,
TableNotFound,
StreamAlreadyCommitted,
StreamNotFound,
InvalidStreamType,
InvalidStreamState,
StreamFinalized,
SchemaMismatchExtraFields,
OffsetAlreadyExists,
OffsetOutOfRange,
CmekNotProvided,
InvalidCmekProvided,
CmekEncryptionError,
KmsServiceError,
KmsPermissionDenied,
UnknownValue(UnknownValue),
}Expand description
Error code for StorageError.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default error.
TableNotFound
Table is not found in the system.
StreamAlreadyCommitted
Stream is already committed.
StreamNotFound
Stream is not found.
InvalidStreamType
Invalid Stream type. For example, you try to commit a stream that is not pending.
InvalidStreamState
Invalid Stream state. For example, you try to commit a stream that is not finalized or is garbaged.
StreamFinalized
Stream is finalized.
SchemaMismatchExtraFields
There is a schema mismatch and it is caused by user schema has extra field than bigquery schema.
OffsetAlreadyExists
Offset already exists.
OffsetOutOfRange
Offset out of range.
CmekNotProvided
Customer-managed encryption key (CMEK) not provided for CMEK-enabled data.
InvalidCmekProvided
Customer-managed encryption key (CMEK) was incorrectly provided.
CmekEncryptionError
There is an encryption error while using customer-managed encryption key.
KmsServiceError
Key Management Service (KMS) service returned an error, which can be retried.
KmsPermissionDenied
Permission denied while using customer-managed encryption key.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using StorageErrorCode::value or StorageErrorCode::name.
Implementations