Progress

Struct Progress 

#[non_exhaustive]
pub struct Progress { pub at_response_start: f64, pub at_response_end: f64, /* private fields */ }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
at_response_start: f64

The fraction of rows assigned to the stream that have been processed by the server so far, not including the rows in the current response message.

This value, along with at_response_end, can be used to interpolate the progress made as the rows in the message are being processed using the following formula: at_response_start + (at_response_end - at_response_start) * rows_processed_from_response / rows_in_response.

Note that if a filter is provided, the at_response_end value of the previous response may not necessarily be equal to the at_response_start value of the current response.

at_response_end: f64

Similar to at_response_start, except that this value includes the rows in the current response.

Implementations

Source

impl Progress

pub fn new() -> Self

Creates a new default instance.

pub fn set_at_response_start<T: Into<f64>>(self, v: T) -> Self

Sets the value of at_response_start.

Example
ⓘ
let x = Progress::new().set_at_response_start(42.0);
pub fn set_at_response_end<T: Into<f64>>(self, v: T) -> Self

Sets the value of at_response_end.

Example
ⓘ
let x = Progress::new().set_at_response_end(42.0);