AppendRowsResponse

Struct AppendRowsResponse 

#[non_exhaustive]
pub struct AppendRowsResponse { pub updated_schema: Option<TableSchema>, pub row_errors: Vec<RowError>, pub write_stream: String, pub response: Option<Response>, /* private fields */ }
Response message for AppendRows.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
updated_schema: Option<TableSchema>

If backend detects a schema update, pass it to user so that user can use it to input new type of message. It will be empty when no schema updates have occurred.

row_errors: Vec<RowError>

If a request failed due to corrupted rows, no rows in the batch will be appended. The API will return row level error info, so that the caller can remove the bad rows and retry the request.

write_stream: String

The target of the append operation. Matches the write_stream in the corresponding request.

response: Option<Response>

Implementations

Source

impl AppendRowsResponse

pub fn new() -> Self

Creates a new default instance.

pub fn set_updated_schema<T>(self, v: T) -> Self
where T: Into<TableSchema>,

Sets the value of updated_schema.

Example
ⓘ
use google_cloud_bigquery::model::TableSchema;
let x = AppendRowsResponse::new().set_updated_schema(TableSchema::default()/* use setters */);
pub fn set_or_clear_updated_schema<T>(self, v: Option<T>) -> Self
where T: Into<TableSchema>,

Sets or clears the value of updated_schema.

Example
ⓘ
use google_cloud_bigquery::model::TableSchema;
let x = AppendRowsResponse::new().set_or_clear_updated_schema(Some(TableSchema::default()/* use setters */));
let x = AppendRowsResponse::new().set_or_clear_updated_schema(None::<TableSchema>);
pub fn set_row_errors<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<RowError>,

Sets the value of row_errors.

Example
ⓘ
use google_cloud_bigquery::model::RowError;
let x = AppendRowsResponse::new()
    .set_row_errors([
        RowError::default()/* use setters */,
        RowError::default()/* use (different) setters */,
    ]);
pub fn set_write_stream<T: Into<String>>(self, v: T) -> Self

Sets the value of write_stream.

Example
ⓘ
let x = AppendRowsResponse::new().set_write_stream("example");
pub fn set_response<T: Into<Option<Response>>>(self, v: T) -> Self

Sets the value of response.

Note that all the setters affecting response are mutually exclusive.

Example
ⓘ
use google_cloud_bigquery::model::append_rows_response::AppendResult;
let x = AppendRowsResponse::new().set_response(Some(
    google_cloud_bigquery::model::append_rows_response::Response::AppendResult(AppendResult::default().into())));
pub fn append_result(&self) -> Option<&Box<AppendResult>>

The value of response if it holds a AppendResult, None if the field is not set or holds a different branch.

pub fn set_append_result<T: Into<Box<AppendResult>>>(self, v: T) -> Self

Sets the value of response to hold a AppendResult.

Note that all the setters affecting response are mutually exclusive.

Example
ⓘ
use google_cloud_bigquery::model::append_rows_response::AppendResult;
let x = AppendRowsResponse::new().set_append_result(AppendResult::default()/* use setters */);
assert!(x.append_result().is_some());
assert!(x.error().is_none());
pub fn error(&self) -> Option<&Box<Status>>

The value of response if it holds a Error, None if the field is not set or holds a different branch.

pub fn set_error<T: Into<Box<Status>>>(self, v: T) -> Self

Sets the value of response to hold a Error.

Note that all the setters affecting response are mutually exclusive.

Example
ⓘ
use google_cloud_rpc::model::Status;
let x = AppendRowsResponse::new().set_error(Status::default()/* use setters */);
assert!(x.error().is_some());
assert!(x.append_result().is_none());