AvroSerializationOptions

Struct AvroSerializationOptions 

#[non_exhaustive]
pub struct AvroSerializationOptions { pub enable_display_name_attribute: bool, pub picos_timestamp_precision: PicosTimestampPrecision, /* private fields */ }
Contains options specific to Avro Serialization.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
enable_display_name_attribute: bool

Enable displayName attribute in Avro schema.

The Avro specification requires field names to be alphanumeric. By default, in cases when column names do not conform to these requirements (e.g. non-ascii unicode codepoints) and Avro is requested as an output format, the CreateReadSession call will fail.

Setting this field to true, populates avro field names with a placeholder value and populates a “displayName” attribute for every avro field with the original column name.

picos_timestamp_precision: PicosTimestampPrecision

Optional. Set timestamp precision option. If not set, the default precision is microseconds.

Implementations

Source

impl AvroSerializationOptions

pub fn new() -> Self

Creates a new default instance.

pub fn set_enable_display_name_attribute<T: Into<bool>>(self, v: T) -> Self

Sets the value of enable_display_name_attribute.

Example
ⓘ
let x = AvroSerializationOptions::new().set_enable_display_name_attribute(true);
pub fn set_picos_timestamp_precision<T: Into<PicosTimestampPrecision>>( self, v: T, ) -> Self

Sets the value of picos_timestamp_precision.

Example
ⓘ
use google_cloud_bigquery::model::avro_serialization_options::PicosTimestampPrecision;
let x0 = AvroSerializationOptions::new().set_picos_timestamp_precision(PicosTimestampPrecision::TimestampPrecisionMicros);
let x1 = AvroSerializationOptions::new().set_picos_timestamp_precision(PicosTimestampPrecision::TimestampPrecisionNanos);
let x2 = AvroSerializationOptions::new().set_picos_timestamp_precision(PicosTimestampPrecision::TimestampPrecisionPicos);