#[non_exhaustive]pub struct BatchCommitWriteStreamsRequest {
pub parent: String,
pub write_streams: Vec<String>,
/* private fields */
}Expand description
Request message for BatchCommitWriteStreams.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Parent table that all the streams should belong to, in the form
of projects/{project}/datasets/{dataset}/tables/{table}.
write_streams: Vec<String>Required. The group of streams that will be committed atomically.
Implementations
Sourceimpl BatchCommitWriteStreamsRequest
impl BatchCommitWriteStreamsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_write_streams<T, V>(self, v: T) -> Self
pub fn set_write_streams<T, V>(self, v: T) -> Self
Sets the value of write_streams.
Example
ⓘ
let x = BatchCommitWriteStreamsRequest::new().set_write_streams(["a", "b", "c"]);Trait Implementations
impl StructuralPartialEq for BatchCommitWriteStreamsRequest