BatchCommitWriteStreamsResponse

Struct BatchCommitWriteStreamsResponse 

#[non_exhaustive]
pub struct BatchCommitWriteStreamsResponse { pub commit_time: Option<Timestamp>, pub stream_errors: Vec<StorageError>, /* private fields */ }
Response message for BatchCommitWriteStreams.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
commit_time: Option<Timestamp>

The time at which streams were committed in microseconds granularity. This field will only exist when there are no stream errors. Note if this field is not set, it means the commit was not successful.

stream_errors: Vec<StorageError>

Stream level error if commit failed. Only streams with error will be in the list. If empty, there is no error and all streams are committed successfully. If non empty, certain streams have errors and ZERO stream is committed due to atomicity guarantee.

Implementations

Source

impl BatchCommitWriteStreamsResponse

pub fn new() -> Self

Creates a new default instance.

pub fn set_commit_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of commit_time.

pub fn set_or_clear_commit_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of commit_time.

pub fn set_stream_errors<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<StorageError>,

Sets the value of stream_errors.