#[non_exhaustive]pub struct CreateReadSessionRequest {
pub parent: String,
pub read_session: Option<ReadSession>,
pub max_stream_count: i32,
pub preferred_min_stream_count: i32,
/* private fields */
}Expand description
Request message for CreateReadSession.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The request project that owns the session, in the form of
projects/{project_id}.
read_session: Option<ReadSession>Required. Session to be created.
max_stream_count: i32Max initial number of streams. If unset or zero, the server will provide a value of streams so as to produce reasonable throughput. Must be non-negative. The number of streams may be lower than the requested number, depending on the amount parallelism that is reasonable for the table. There is a default system max limit of 1,000.
This must be greater than or equal to preferred_min_stream_count. Typically, clients should either leave this unset to let the system to determine an upper bound OR set this a size for the maximum “units of work” it can gracefully handle.
preferred_min_stream_count: i32The minimum preferred stream count. This parameter can be used to inform the service that there is a desired lower bound on the number of streams. This is typically a target parallelism of the client (e.g. a Spark cluster with N-workers would set this to a low multiple of N to ensure good cluster utilization).
The system will make a best effort to provide at least this number of streams, but in some cases might provide less.
Implementations
Sourceimpl CreateReadSessionRequest
impl CreateReadSessionRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_read_session<T>(self, v: T) -> Selfwhere
T: Into<ReadSession>,
pub fn set_read_session<T>(self, v: T) -> Selfwhere
T: Into<ReadSession>,
Sets the value of read_session.
Example
use google_cloud_bigquery::model::ReadSession;
let x = CreateReadSessionRequest::new().set_read_session(ReadSession::default()/* use setters */);Sourcepub fn set_or_clear_read_session<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReadSession>,
pub fn set_or_clear_read_session<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReadSession>,
Sets or clears the value of read_session.
Example
use google_cloud_bigquery::model::ReadSession;
let x = CreateReadSessionRequest::new().set_or_clear_read_session(Some(ReadSession::default()/* use setters */));
let x = CreateReadSessionRequest::new().set_or_clear_read_session(None::<ReadSession>);Sourcepub fn set_max_stream_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_max_stream_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of max_stream_count.
Example
let x = CreateReadSessionRequest::new().set_max_stream_count(42);Sourcepub fn set_preferred_min_stream_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_preferred_min_stream_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of preferred_min_stream_count.
Example
let x = CreateReadSessionRequest::new().set_preferred_min_stream_count(42);Trait Implementations
Sourceimpl Clone for CreateReadSessionRequest
impl Clone for CreateReadSessionRequest
Sourceimpl Debug for CreateReadSessionRequest
impl Debug for CreateReadSessionRequest
Sourceimpl Default for CreateReadSessionRequest
impl Default for CreateReadSessionRequest
Sourceimpl Message for CreateReadSessionRequest
impl Message for CreateReadSessionRequest
Sourceimpl PartialEq for CreateReadSessionRequest
impl PartialEq for CreateReadSessionRequest
impl StructuralPartialEq for CreateReadSessionRequest