#[non_exhaustive]pub struct GetWriteStreamRequest {
pub name: String,
pub view: WriteStreamView,
/* private fields */
}Expand description
Request message for GetWriteStreamRequest.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Name of the stream to get, in the form of
projects/{project}/datasets/{dataset}/tables/{table}/streams/{stream}.
view: WriteStreamViewIndicates whether to get full or partial view of the WriteStream. If not set, view returned will be basic.
Implementations