#[non_exhaustive]pub struct ProtoSchema {
pub proto_descriptor: Option<DescriptorProto>,
/* private fields */
}Expand description
ProtoSchema describes the schema of the serialized protocol buffer data rows.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.proto_descriptor: Option<DescriptorProto>Descriptor for input message. The provided descriptor must be self contained, such that data rows sent can be fully decoded using only the single descriptor. For data rows that are compositions of multiple independent messages, this means the descriptor may need to be transformed to only use nested types: https://developers.google.com/protocol-buffers/docs/proto#nested
For additional information for how proto types and values map onto BigQuery see: https://cloud.google.com/bigquery/docs/write-api#data_type_conversions
Implementations
Sourceimpl ProtoSchema
impl ProtoSchema
Sourcepub fn set_proto_descriptor<T>(self, v: T) -> Selfwhere
T: Into<DescriptorProto>,
pub fn set_proto_descriptor<T>(self, v: T) -> Selfwhere
T: Into<DescriptorProto>,
Sets the value of proto_descriptor.
Example
ⓘ
use wkt::DescriptorProto;
let x = ProtoSchema::new().set_proto_descriptor(DescriptorProto::default()/* use setters */);Sourcepub fn set_or_clear_proto_descriptor<T>(self, v: Option<T>) -> Selfwhere
T: Into<DescriptorProto>,
pub fn set_or_clear_proto_descriptor<T>(self, v: Option<T>) -> Selfwhere
T: Into<DescriptorProto>,
Sets or clears the value of proto_descriptor.
Example
ⓘ
use wkt::DescriptorProto;
let x = ProtoSchema::new().set_or_clear_proto_descriptor(Some(DescriptorProto::default()/* use setters */));
let x = ProtoSchema::new().set_or_clear_proto_descriptor(None::<DescriptorProto>);Trait Implementations
Sourceimpl Clone for ProtoSchema
impl Clone for ProtoSchema
Sourceimpl Debug for ProtoSchema
impl Debug for ProtoSchema
Sourceimpl Default for ProtoSchema
impl Default for ProtoSchema
Sourceimpl Message for ProtoSchema
impl Message for ProtoSchema
Sourceimpl PartialEq for ProtoSchema
impl PartialEq for ProtoSchema
impl StructuralPartialEq for ProtoSchema