#[non_exhaustive]pub struct ReadRowsRequest {
pub read_stream: String,
pub offset: i64,
pub output_format_serialization_options: Option<OutputFormatSerializationOptions>,
/* private fields */
}Expand description
Request message for ReadRows.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.read_stream: StringRequired. Stream to read rows from.
offset: i64The offset requested must be less than the last row read from Read. Requesting a larger offset is undefined. If not specified, start reading from offset zero.
output_format_serialization_options: Option<OutputFormatSerializationOptions>Specifies output serialization options. Only job _default streams are supported.
This feature is not yet available.
Implementations
Sourceimpl ReadRowsRequest
impl ReadRowsRequest
Sourcepub fn set_read_stream<T: Into<String>>(self, v: T) -> Self
pub fn set_read_stream<T: Into<String>>(self, v: T) -> Self
Sets the value of read_stream.
Example
let x = ReadRowsRequest::new().set_read_stream(format!("projects/{project_id}/locations/{location_id}/sessions/{session_id}/streams/{stream_id}"));Sourcepub fn set_offset<T: Into<i64>>(self, v: T) -> Self
pub fn set_offset<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_output_format_serialization_options<T: Into<Option<OutputFormatSerializationOptions>>>(
self,
v: T,
) -> Self
pub fn set_output_format_serialization_options<T: Into<Option<OutputFormatSerializationOptions>>>( self, v: T, ) -> Self
Sets the value of output_format_serialization_options.
Note that all the setters affecting output_format_serialization_options are mutually
exclusive.
Example
use google_cloud_bigquery::model::ArrowSerializationOptions;
let x = ReadRowsRequest::new().set_output_format_serialization_options(Some(
google_cloud_bigquery::model::read_rows_request::OutputFormatSerializationOptions::ArrowSerializationOptions(ArrowSerializationOptions::default().into())));Sourcepub fn arrow_serialization_options(
&self,
) -> Option<&Box<ArrowSerializationOptions>>
pub fn arrow_serialization_options( &self, ) -> Option<&Box<ArrowSerializationOptions>>
The value of output_format_serialization_options
if it holds a ArrowSerializationOptions, None if the field is not set or
holds a different branch.
Sourcepub fn set_arrow_serialization_options<T: Into<Box<ArrowSerializationOptions>>>(
self,
v: T,
) -> Self
pub fn set_arrow_serialization_options<T: Into<Box<ArrowSerializationOptions>>>( self, v: T, ) -> Self
Sets the value of output_format_serialization_options
to hold a ArrowSerializationOptions.
Note that all the setters affecting output_format_serialization_options are
mutually exclusive.
Example
use google_cloud_bigquery::model::ArrowSerializationOptions;
let x = ReadRowsRequest::new().set_arrow_serialization_options(ArrowSerializationOptions::default()/* use setters */);
assert!(x.arrow_serialization_options().is_some());Trait Implementations
Sourceimpl Clone for ReadRowsRequest
impl Clone for ReadRowsRequest
Sourceimpl Debug for ReadRowsRequest
impl Debug for ReadRowsRequest
Sourceimpl Default for ReadRowsRequest
impl Default for ReadRowsRequest
Sourceimpl Message for ReadRowsRequest
impl Message for ReadRowsRequest
Sourceimpl PartialEq for ReadRowsRequest
impl PartialEq for ReadRowsRequest
impl StructuralPartialEq for ReadRowsRequest