#[non_exhaustive]pub struct RowError {
pub index: i64,
pub code: RowErrorCode,
pub message: String,
/* private fields */
}Expand description
The message that presents row level error info in a request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.index: i64Index of the malformed row in the request.
code: RowErrorCodeStructured error reason for a row error.
message: StringDescription of the issue encountered when processing the row.
Implementations