#[non_exhaustive]pub struct SplitReadStreamResponse {
pub primary_stream: Option<ReadStream>,
pub remainder_stream: Option<ReadStream>,
/* private fields */
}Expand description
Response message for SplitReadStream.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.primary_stream: Option<ReadStream>Primary stream, which contains the beginning portion of |original_stream|. An empty value indicates that the original stream can no longer be split.
remainder_stream: Option<ReadStream>Remainder stream, which contains the tail of |original_stream|. An empty value indicates that the original stream can no longer be split.
Implementations
Sourceimpl SplitReadStreamResponse
impl SplitReadStreamResponse
Sourcepub fn set_primary_stream<T>(self, v: T) -> Selfwhere
T: Into<ReadStream>,
pub fn set_primary_stream<T>(self, v: T) -> Selfwhere
T: Into<ReadStream>,
Sets the value of primary_stream.
Example
ⓘ
use google_cloud_bigquery::model::ReadStream;
let x = SplitReadStreamResponse::new().set_primary_stream(ReadStream::default()/* use setters */);Sourcepub fn set_or_clear_primary_stream<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReadStream>,
pub fn set_or_clear_primary_stream<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReadStream>,
Sets or clears the value of primary_stream.
Example
ⓘ
use google_cloud_bigquery::model::ReadStream;
let x = SplitReadStreamResponse::new().set_or_clear_primary_stream(Some(ReadStream::default()/* use setters */));
let x = SplitReadStreamResponse::new().set_or_clear_primary_stream(None::<ReadStream>);Sourcepub fn set_remainder_stream<T>(self, v: T) -> Selfwhere
T: Into<ReadStream>,
pub fn set_remainder_stream<T>(self, v: T) -> Selfwhere
T: Into<ReadStream>,
Sets the value of remainder_stream.
Example
ⓘ
use google_cloud_bigquery::model::ReadStream;
let x = SplitReadStreamResponse::new().set_remainder_stream(ReadStream::default()/* use setters */);Sourcepub fn set_or_clear_remainder_stream<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReadStream>,
pub fn set_or_clear_remainder_stream<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReadStream>,
Sets or clears the value of remainder_stream.
Example
ⓘ
use google_cloud_bigquery::model::ReadStream;
let x = SplitReadStreamResponse::new().set_or_clear_remainder_stream(Some(ReadStream::default()/* use setters */));
let x = SplitReadStreamResponse::new().set_or_clear_remainder_stream(None::<ReadStream>);Trait Implementations
Sourceimpl Clone for SplitReadStreamResponse
impl Clone for SplitReadStreamResponse
Sourceimpl Debug for SplitReadStreamResponse
impl Debug for SplitReadStreamResponse
Sourceimpl Default for SplitReadStreamResponse
impl Default for SplitReadStreamResponse
Sourceimpl Message for SplitReadStreamResponse
impl Message for SplitReadStreamResponse
Sourceimpl PartialEq for SplitReadStreamResponse
impl PartialEq for SplitReadStreamResponse
impl StructuralPartialEq for SplitReadStreamResponse