TableFieldSchema

Struct TableFieldSchema 

#[non_exhaustive]
pub struct TableFieldSchema { pub name: String, pub type: Type, pub mode: Mode, pub fields: Vec<TableFieldSchema>, pub description: String, pub max_length: i64, pub precision: i64, pub scale: i64, pub default_value_expression: String, pub timestamp_precision: Option<Int64Value>, pub range_element_type: Option<FieldElementType>, /* private fields */ }
TableFieldSchema defines a single field/column within a table schema.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Required. The field name. The name must contain only letters (a-z, A-Z), numbers (0-9), or underscores (_), and must start with a letter or underscore. The maximum length is 128 characters.

type: Type

Required. The field data type.

mode: Mode

Optional. The field mode. The default value is NULLABLE.

fields: Vec<TableFieldSchema>

Optional. Describes the nested schema fields if the type property is set to STRUCT.

description: String

Optional. The field description. The maximum length is 1,024 characters.

max_length: i64

Optional. Maximum length of values of this field for STRINGS or BYTES.

If max_length is not specified, no maximum length constraint is imposed on this field.

If type = “STRING”, then max_length represents the maximum UTF-8 length of strings in this field.

If type = “BYTES”, then max_length represents the maximum number of bytes in this field.

It is invalid to set this field if type is not “STRING” or “BYTES”.

precision: i64

Optional. Precision (maximum number of total digits in base 10) and scale (maximum number of digits in the fractional part in base 10) constraints for values of this field for NUMERIC or BIGNUMERIC.

It is invalid to set precision or scale if type is not “NUMERIC” or “BIGNUMERIC”.

If precision and scale are not specified, no value range constraint is imposed on this field insofar as values are permitted by the type.

Values of this NUMERIC or BIGNUMERIC field must be in this range when:

  • Precision (P) and scale (S) are specified: [-10^(P-S) + 10^(-S), 10^(P-S) - 10^(-S)]
  • Precision (P) is specified but not scale (and thus scale is interpreted to be equal to zero): [-10^P + 1, 10^P - 1].

Acceptable values for precision and scale if both are specified:

  • If type = “NUMERIC”: 1 <= precision - scale <= 29 and 0 <= scale <= 9.
  • If type = “BIGNUMERIC”: 1 <= precision - scale <= 38 and 0 <= scale <= 38.

Acceptable values for precision if only precision is specified but not scale (and thus scale is interpreted to be equal to zero):

  • If type = “NUMERIC”: 1 <= precision <= 29.
  • If type = “BIGNUMERIC”: 1 <= precision <= 38.

If scale is specified but not precision, then it is invalid.

scale: i64

Optional. See documentation for precision.

default_value_expression: String

Optional. A SQL expression to specify the [default value] (https://cloud.google.com/bigquery/docs/default-values) for this field.

timestamp_precision: Option<Int64Value>

Optional. Precision (maximum number of total digits in base 10) for seconds of TIMESTAMP type.

Possible values include:

  • 6 (Default, for TIMESTAMP type with microsecond precision)
  • 12 (For TIMESTAMP type with picosecond precision)
range_element_type: Option<FieldElementType>

Optional. The subtype of the RANGE, if the type of this field is RANGE. If the type is RANGE, this field is required. Possible values for the field element type of a RANGE include:

  • DATE
  • DATETIME
  • TIMESTAMP

Implementations

Source

impl TableFieldSchema

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

pub fn set_type<T: Into<Type>>(self, v: T) -> Self

Sets the value of r#type.

pub fn set_mode<T: Into<Mode>>(self, v: T) -> Self

Sets the value of mode.

pub fn set_fields<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<TableFieldSchema>,

Sets the value of fields.

pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

pub fn set_max_length<T: Into<i64>>(self, v: T) -> Self

Sets the value of max_length.

pub fn set_precision<T: Into<i64>>(self, v: T) -> Self

Sets the value of precision.

pub fn set_scale<T: Into<i64>>(self, v: T) -> Self

Sets the value of scale.

pub fn set_default_value_expression<T: Into<String>>(self, v: T) -> Self

Sets the value of default_value_expression.

pub fn set_timestamp_precision<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of timestamp_precision.

pub fn set_or_clear_timestamp_precision<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of timestamp_precision.

pub fn set_range_element_type<T>(self, v: T) -> Self

Sets the value of range_element_type.

pub fn set_or_clear_range_element_type<T>(self, v: Option<T>) -> Self

Sets or clears the value of range_element_type.