WriteStream

Struct WriteStream 

#[non_exhaustive]
pub struct WriteStream { pub name: String, pub type: Type, pub create_time: Option<Timestamp>, pub commit_time: Option<Timestamp>, pub table_schema: Option<TableSchema>, pub write_mode: WriteMode, pub location: String, /* private fields */ }
Information about a single stream that gets data inside the storage system.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Output only. Name of the stream, in the form projects/{project}/datasets/{dataset}/tables/{table}/streams/{stream}.

type: Type

Immutable. Type of the stream.

create_time: Option<Timestamp>

Output only. Create time of the stream. For the _default stream, this is the creation_time of the table.

commit_time: Option<Timestamp>

Output only. Commit time of the stream. If a stream is of COMMITTED type, then it will have a commit_time same as create_time. If the stream is of PENDING type, empty commit_time means it is not committed.

table_schema: Option<TableSchema>

Output only. The schema of the destination table. It is only returned in CreateWriteStream response. Caller should generate data that’s compatible with this schema to send in initial AppendRowsRequest. The table schema could go out of date during the life time of the stream.

write_mode: WriteMode

Immutable. Mode of the stream.

location: String

Output only. The geographic location where the stream’s dataset resides. See https://cloud.google.com/bigquery/docs/locations for supported locations.

Implementations

Source

impl WriteStream

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
ⓘ
let x = WriteStream::new().set_name(format!("projects/{project_id}/datasets/{dataset_id}/tables/{table_id}/streams/{stream_id}"));
pub fn set_type<T: Into<Type>>(self, v: T) -> Self

Sets the value of r#type.

Example
ⓘ
use google_cloud_bigquery::model::write_stream::Type;
let x0 = WriteStream::new().set_type(Type::Committed);
let x1 = WriteStream::new().set_type(Type::Pending);
let x2 = WriteStream::new().set_type(Type::Buffered);
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
ⓘ
use wkt::Timestamp;
let x = WriteStream::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
ⓘ
use wkt::Timestamp;
let x = WriteStream::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = WriteStream::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_commit_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of commit_time.

Example
ⓘ
use wkt::Timestamp;
let x = WriteStream::new().set_commit_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_commit_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of commit_time.

Example
ⓘ
use wkt::Timestamp;
let x = WriteStream::new().set_or_clear_commit_time(Some(Timestamp::default()/* use setters */));
let x = WriteStream::new().set_or_clear_commit_time(None::<Timestamp>);
pub fn set_table_schema<T>(self, v: T) -> Self
where T: Into<TableSchema>,

Sets the value of table_schema.

Example
ⓘ
use google_cloud_bigquery::model::TableSchema;
let x = WriteStream::new().set_table_schema(TableSchema::default()/* use setters */);
pub fn set_or_clear_table_schema<T>(self, v: Option<T>) -> Self
where T: Into<TableSchema>,

Sets or clears the value of table_schema.

Example
ⓘ
use google_cloud_bigquery::model::TableSchema;
let x = WriteStream::new().set_or_clear_table_schema(Some(TableSchema::default()/* use setters */));
let x = WriteStream::new().set_or_clear_table_schema(None::<TableSchema>);
pub fn set_write_mode<T: Into<WriteMode>>(self, v: T) -> Self

Sets the value of write_mode.

Example
ⓘ
use google_cloud_bigquery::model::write_stream::WriteMode;
let x0 = WriteStream::new().set_write_mode(WriteMode::Insert);
pub fn set_location<T: Into<String>>(self, v: T) -> Self

Sets the value of location.

Example
ⓘ
let x = WriteStream::new().set_location("example");