Module model_ext

Module model_ext 

Extends crate::model.

Note that there is no real distinction between the types in model and model_ext. The two modules are separate for library maintenance reasons.

Structs

AppendResponse
The return type of an append() operation.
CompleteQueryMetadata
QueryMetadata
QueryRequest