Module query

Module query 

Types related to querying with a BigQuery client.

Modules

retry_policy
Defines a retry policy for BigQuery.

Structs

CompleteQuery
A handle representing a successfully completed query ready for reading results.
Query
A handle representing a running or completed SQL query execution.
Row
A container for a single row within a query result set.
RowIterator
An iterator over rows returned by a query.
SqlValue
An opaque representation of a BigQuery SQL cell value.

Traits

ColumnIndex
A trait for types that can be used to index into a Row or SqlValue.
FromSql
A trait for converting BigQuery value representations into Rust types.

Derive Macros

FromRow
Derives standard library TryFrom for converting a BigQuery Row into a struct.
FromSql
Derives FromSql for converting a BigQuery value into a struct.