pub struct RowIterator { /* private fields */ }Expand description
An iterator over rows returned by a query.
CompleteQuery::read() returns a
RowIterator.
RowIterator yields rows from the query result set, automatically requesting
subsequent pages from BigQuery as needed until the entire result set has been consumed.
Example
let mut rows = client
.query("SELECT name, state FROM `bigquery-public-data.usa_names.usa_1910_2013` LIMIT 10")
.until_done()
.await?
.read();
while let Some(row) = rows.next().await.transpose()? {
let name: String = row.get("name");
let state: String = row.get("state");
println!("{name} from {state}");
}Implementations
Sourceimpl RowIterator
impl RowIterator
Sourcepub fn set_max_results(self, max_results: u32) -> Self
pub fn set_max_results(self, max_results: u32) -> Self
Sets the maximum number of rows to buffer in memory.
This controls page size during network fetches when streaming result sets.
Example
let mut rows = client
.query("SELECT 1 AS n")
.until_done()
.await?
.read()
.set_max_results(500);Trait Implementations