ColumnIndex

Trait ColumnIndex 

pub trait ColumnIndex: ColumnIndex + Display { }
A trait for types that can be used to index into a Row or SqlValue.

This trait is sealed and cannot be implemented for types outside of this crate.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ColumnIndex for &str

Source

impl ColumnIndex for String

Source

impl ColumnIndex for usize

Implementors