day_dyn

Function day_dyn 

pub fn day_dyn(array: &dyn Array) -> Result<Arc<dyn Array>, ArrowError>
👎Deprecated since 51.0.0:

Use date_part instead

Extracts the day of a given temporal array as an array of integers.

If the given array isn’t temporal primitive or dictionary array, an Err will be returned.