hour

Function hour 

pub fn hour<T>(
    array: &PrimitiveArray<T>,
) -> Result<PrimitiveArray<Int32Type>, ArrowError>
👎Deprecated since 51.0.0:

Use date_part instead

Extracts the hours of a given temporal primitive array as an array of integers within the range of [0, 23].