minute_dyn

Function minute_dyn 

pub fn minute_dyn(array: &dyn Array) -> Result<Arc<dyn Array>, ArrowError>
👎Deprecated since 51.0.0:

Use date_part instead

Extracts the minutes of a given temporal array as an array of integers. If the given array isn’t temporal primitive or dictionary array, an Err will be returned.