month

Function month 

pub fn month<T>(
    array: &PrimitiveArray<T>,
) -> Result<PrimitiveArray<Int32Type>, ArrowError>
👎Deprecated since 51.0.0:

Use date_part instead

Extracts the month of a given temporal primitive array as an array of integers within the range of [1, 12].