microsecond_dyn

Function microsecond_dyn 

pub fn microsecond_dyn(array: &dyn Array) -> Result<Arc<dyn Array>, ArrowError>
👎Deprecated since 51.0.0:

Use date_part instead

Extracts the microseconds of a given temporal primitive array as an array of integers. If the given array isn’t temporal primitive or dictionary array, an Err will be returned.