pub trait RecordBatchReader: Iterator<Item = Result<RecordBatch, ArrowError>> {
// Required method
fn schema(&self) -> Arc<Schema> ⓘ;
// Provided method
fn next_batch(&mut self) -> Result<Option<RecordBatch>, ArrowError> { ... }
}Expand description
Trait for types that can read RecordBatch’s.
To create from an iterator, see RecordBatchIterator.
Required Methods
Provided Methods
Sourcefn next_batch(&mut self) -> Result<Option<RecordBatch>, ArrowError>
👎Deprecated since 2.0.0: This method is deprecated in favour of next from the trait Iterator.
fn next_batch(&mut self) -> Result<Option<RecordBatch>, ArrowError>
This method is deprecated in favour of next from the trait Iterator.
Reads the next RecordBatch.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".