Module write

Module write 

Types related to writing with a Write client.

Modules

format
Defines the data formats accepted by a writer.
retry_policy
Defines the retry policy for the BigQuery Storage Write API.
stream_type
Defines marker traits and types for the stream writers.

Structs

AppendFuture
A future that resolves to the result of an async append operation.
BufferedWriter
A writer for a buffered stream.
CommittedWriter
A writer for a committed stream.
DefaultWriter
A writer for the default stream.
PendingWriter
A writer for a pending stream.