pub struct BufferedWriter { /* private fields */ }Expand description
A writer for a buffered stream.
Implementations
Sourceimpl BufferedWriter
impl BufferedWriter
Sourcepub fn write_stream(&self) -> &str
pub fn write_stream(&self) -> &str
Return the full resource name of the underlying write stream.
Sourcepub fn append(&self, rows: ArrowRecordBatch) -> AppendWithOffset
pub fn append(&self, rows: ArrowRecordBatch) -> AppendWithOffset
Append rows to the buffered stream.
Sourcepub async fn flush(&self, offset: i64) -> Result<FlushRowsResponse>
pub async fn flush(&self, offset: i64) -> Result<FlushRowsResponse>
Flush the buffered stream, making rows up to the specified offset available for reading.
Sourcepub async fn finalize(&self) -> Result<FinalizeWriteStreamResponse>
pub async fn finalize(&self) -> Result<FinalizeWriteStreamResponse>
Finalize the buffered stream, preventing further writes.