pub trait Writer: Writer + Sized { }Expand description
A trait for strongly-typed stream writers that can be attached to an existing stream.
This trait is sealed and cannot be implemented for types outside of this crate.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".