BufferedWriter

Struct BufferedWriter 

pub struct BufferedWriter<F> { /* private fields */ }
A writer for a buffered stream.

In a buffered stream, row-level commits are provided, and records are buffered until the rows are committed by flushing the stream. This is an advanced stream type; if you have small batches that you want to guarantee appear together, consider using a committed stream and sending each batch in one request.

Implementations

Source

impl<F> BufferedWriter<F>
where F: DataFormat,

pub fn write_stream(&self) -> &str

Returns the full resource name of the underlying write stream.

pub fn append(&self, rows: F::Rows) -> AppendWithOffset

Appends rows to the buffered stream.

pub async fn flush(&self, offset: i64) -> Result<FlushRowsResponse>

Flush the buffered stream, making rows up to and including the specified offset available for reading.

Stream offsets are 0-indexed and offset is inclusive. For example, after appending a batch of 10 rows starting at offset 0 (occupying offsets 0..=9), calling flush(9) flushes all 10 rows.

Example
// Append 10 rows starting at offset 0 (offsets 0..=9).
let _ = writer.append(ten_rows()).set_offset(0).send().await?;

// Flush rows up to and including offset 9.
let _ = writer.flush(9).await?;

use google_cloud_bigquery::model::ArrowRecordBatch;
fn ten_rows() -> ArrowRecordBatch {
    todo!("Serialize 10 rows...")
}
pub async fn finalize(&self) -> Result<FinalizeWriteStreamResponse>

Finalizes the buffered stream, preventing further writes.