pub struct CommittedWriter<F> { /* private fields */ }Expand description
A writer for a committed stream.
In a committed stream, records are available for reading immediately as you write them to the stream. Use this type for streaming workloads that need minimal read latency and exactly-once semantics through the use of stream offsets.
Implementations
Sourceimpl<F> CommittedWriter<F>where
F: DataFormat,
impl<F> CommittedWriter<F>where
F: DataFormat,
Sourcepub fn write_stream(&self) -> &str
pub fn write_stream(&self) -> &str
Returns the full resource name of the underlying write stream.
Sourcepub fn append(&self, rows: F::Rows) -> AppendWithOffset
pub fn append(&self, rows: F::Rows) -> AppendWithOffset
Appends rows to the committed stream.
Sourcepub async fn finalize(&self) -> Result<FinalizeWriteStreamResponse>
pub async fn finalize(&self) -> Result<FinalizeWriteStreamResponse>
Finalizes the stream, preventing further writes.