pub struct DefaultWriter<F> { /* private fields */ }Expand description
A writer for the default stream.
The default stream is designed for streaming scenarios where you have continuously arriving data. It has the following characteristics:
- Data written to the default stream is available immediately for query.
- The default stream supports at-least-once semantics.
- You don’t need to explicitly create the default stream.
Implementations
Sourceimpl<F> DefaultWriter<F>where
F: DataFormat,
impl<F> DefaultWriter<F>where
F: DataFormat,