pub struct PendingWriter<F> { /* private fields */ }Expand description
A writer for a pending stream.
In a pending stream, records are buffered in a pending state until you commit the stream. When you commit a stream, all of the pending data becomes available for reading atomically. Use this type for batch workloads, as an alternative to BigQuery load jobs.
Implementations
Sourceimpl<F> PendingWriter<F>where
F: DataFormat,
impl<F> PendingWriter<F>where
F: DataFormat,
Sourcepub fn write_stream(&self) -> &str
pub fn write_stream(&self) -> &str
Returns the full resource name of the underlying write stream.
Sourcepub fn append(&self, rows: F::Rows) -> AppendWithOffset
pub fn append(&self, rows: F::Rows) -> AppendWithOffset
Appends rows to the pending stream.
Sourcepub async fn finalize(&self) -> Result<FinalizeWriteStreamResponse>
pub async fn finalize(&self) -> Result<FinalizeWriteStreamResponse>
Finalizes the pending stream, preventing further writes.
Sourcepub async fn commit(
&self,
) -> Result<BatchCommitWriteStreamsResponse, CommitError>
pub async fn commit( &self, ) -> Result<BatchCommitWriteStreamsResponse, CommitError>
Commits the pending stream to the table.
The stream must be finalized via finalize before
calling commit.