ClientBuilder

Struct ClientBuilder 

pub struct ClientBuilder { /* private fields */ }
A builder for BigQuery.

Example

let builder = BigQuery::builder();
let client = builder
    .with_endpoint("https://bigquery.googleapis.com")
    .build()
    .await?;

Implementations

Source

impl ClientBuilder

pub fn new() -> Self

Creates a new default ClientBuilder.

pub fn with_project_id<V: Into<String>>(self, project_id: V) -> Self

Sets the default Google Cloud project ID for the client.

Example
let client = BigQuery::builder()
    .with_project_id("my-project-id")
    .build()
    .await?;
pub fn with_endpoint<V: Into<String>>(self, v: V) -> Self

Sets the BigQuery v2 API endpoint.

Example
let client = BigQuery::builder()
    .with_endpoint("https://private.googleapis.com")
    .build()
    .await?;
pub fn with_credentials<V: Into<Credentials>>(self, credentials: V) -> Self

Configure the authentication credentials.

Most Google Cloud services require authentication, though some services allow for anonymous access, and some services provide emulators where no authentication is required. More information about valid credentials types can be found in the google-cloud-auth crate documentation.

Example
use google_cloud_auth::credentials::mds;
let client = BigQuery::builder()
    .with_credentials(
        mds::Builder::default()
            .with_scopes(["https://www.googleapis.com/auth/cloud-platform.read-only"])
            .build()?)
    .build()
    .await?;
pub fn with_universe_domain<V: Into<String>>(self, v: V) -> Self

Configure the universe domain.

The universe domain is the default service domain for a given cloud universe. The default value is “googleapis.com”.

Example
let client = BigQuery::builder()
    .with_universe_domain("googleapis.com")
    .build()
    .await?;
pub fn with_tracing(self) -> Self

Enables tracing.

The client libraries can be dynamically instrumented with the Tokio tracing framework. Setting this flag enables this instrumentation.

Example
let client = BigQuery::builder()
    .with_tracing()
    .build()
    .await?;
pub async fn build(self) -> Result<BigQuery>

Creates a new BigQuery client.

Example
let client = BigQuery::builder().build().await?;