pub struct ClientBuilder { /* private fields */ }Expand description
Implementations
Sourceimpl ClientBuilder
impl ClientBuilder
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new default ClientBuilder.
Sourcepub fn with_project_id<V: Into<String>>(self, project_id: V) -> Self
pub fn with_project_id<V: Into<String>>(self, project_id: V) -> Self
Sets the default Google Cloud project ID for the client.
Example
let client = BigQuery::builder()
.with_project_id("my-project-id")
.build()
.await?;Sourcepub fn with_endpoint<V: Into<String>>(self, v: V) -> Self
pub fn with_endpoint<V: Into<String>>(self, v: V) -> Self
Sets the BigQuery v2 API endpoint.
Example
let client = BigQuery::builder()
.with_endpoint("https://private.googleapis.com")
.build()
.await?;Sourcepub fn with_credentials<V: Into<Credentials>>(self, credentials: V) -> Self
pub fn with_credentials<V: Into<Credentials>>(self, credentials: V) -> Self
Configure the authentication credentials.
Most Google Cloud services require authentication, though some services allow for anonymous access, and some services provide emulators where no authentication is required. More information about valid credentials types can be found in the google-cloud-auth crate documentation.
Example
use google_cloud_auth::credentials::mds;
let client = BigQuery::builder()
.with_credentials(
mds::Builder::default()
.with_scopes(["https://www.googleapis.com/auth/cloud-platform.read-only"])
.build()?)
.build()
.await?;Sourcepub fn with_universe_domain<V: Into<String>>(self, v: V) -> Self
pub fn with_universe_domain<V: Into<String>>(self, v: V) -> Self
Configure the universe domain.
The universe domain is the default service domain for a given cloud universe. The default value is “googleapis.com”.
Example
let client = BigQuery::builder()
.with_universe_domain("googleapis.com")
.build()
.await?;Sourcepub fn with_tracing(self) -> Self
pub fn with_tracing(self) -> Self