Request and client builders for the Write client.
Structs
- Append
- A request builder for appending rows to the default stream.
- Append
With Offset - A request builder for appending rows to an application-created stream, with an optional stream offset to ensure exactly-once semantics.
- Client
Builder - A builder for Write.
- Writer
Builder - A builder to create a stream writer.