pub struct Write { /* private fields */ }Expand description
A client for BigQuery Storage Write API.
Implementations
Sourceimpl Write
impl Write
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Creates a new ClientBuilder.
Sourcepub fn open_default_stream<T: Into<String>>(
&self,
table: T,
) -> WriterBuilder<DefaultStream>
pub fn open_default_stream<T: Into<String>>( &self, table: T, ) -> WriterBuilder<DefaultStream>
Opens the default stream for the given table.
Example
let writer = client
.open_default_stream("projects/my-project/datasets/my-dataset/tables/my-table")
.build_arrow(schema())
.await?;
use google_cloud_bigquery::model::ArrowSchema;
fn schema() -> ArrowSchema {
todo!("Define your table's schema...")
}Sourcepub fn create_stream<S: ApplicationCreatedStream, T: Into<String>>(
&self,
table: T,
) -> WriterBuilder<S>
pub fn create_stream<S: ApplicationCreatedStream, T: Into<String>>( &self, table: T, ) -> WriterBuilder<S>
Creates a new application-created stream for the given table.
The stream type S can be inferred from the variable’s writer type
annotation
(PendingWriter,
CommittedWriter, or
BufferedWriter) or specified explicitly via turbofish
(create_stream::<PendingStream, _>(...)).
Example
use google_cloud_bigquery::write::PendingWriter;
use google_cloud_bigquery::write::format::Arrow;
let writer: PendingWriter<Arrow> = client
.create_stream("projects/my-project/datasets/my-dataset/tables/my-table")
.build_arrow(schema())
.await?;
use google_cloud_bigquery::model::ArrowSchema;
fn schema() -> ArrowSchema {
todo!("Define your table's schema...")
}Sourcepub fn attach_to_stream<S: ApplicationCreatedStream, T: Into<String>>(
&self,
write_stream: T,
) -> WriterBuilder<S>
pub fn attach_to_stream<S: ApplicationCreatedStream, T: Into<String>>( &self, write_stream: T, ) -> WriterBuilder<S>
Attaches to an existing application-created stream.
The stream type S can be inferred from the variable’s writer type
annotation
(PendingWriter,
CommittedWriter, or
BufferedWriter) or specified explicitly via turbofish
(attach_to_stream::<PendingStream, _>(...)).
Example
use google_cloud_bigquery::write::CommittedWriter;
use google_cloud_bigquery::write::format::Arrow;
let writer: CommittedWriter<Arrow> = client
.attach_to_stream("projects/my-project/datasets/my_dataset/tables/my_table/streams/my_stream")
.build_arrow(schema())
.await?;Trait Implementations