Custom errors for the BigQuery clients.
Enums
- Append
Error - Represents an error that can occur when appending rows.
- Commit
Error - Represents an error that can occur when committing a pending write stream.
- Convert
Error - Represents failures when converting a BigQuery cell value to a Rust type.
- Query
Error - Errors that can occur during query configuration, execution, or polling.
- RowError
- Errors that can occur when retrieving value cells from a Row or iterating over query results.
- Writer
Builder Error - Represents an error that can occur when building a writer.