Module error

Module error 

Custom errors for the BigQuery clients.

Enums

AppendError
Represents an error that can occur when appending rows.
AttachError
Represents an error that can occur when attaching to an existing stream.
ConvertError
Represents failures when converting a raw BigQuery cell value (wkt::Value) to a Rust type.
QueryError
Errors that can occur during query configuration, execution, or polling.
RowError
Errors that can occur when retrieving value cells from a Row or iterating over query results.