Custom errors for the BigQuery clients.
Enums
- Append
Error - Represents an error that can occur when appending rows.
- Attach
Error - Represents an error that can occur when attaching to an existing stream.
- Convert
Error - Represents failures when converting a raw BigQuery cell value (
wkt::Value) to a Rust type. - Query
Error - Errors that can occur during query configuration, execution, or polling.
- RowError
- Errors that can occur when retrieving value cells from a Row or iterating over query results.