Module model

Module model 

The messages and enums that are part of this client library

Modules

row_error
Defines additional types related to RowError.
storage_error
Defines additional types related to StorageError.
table_field_schema
Defines additional types related to TableFieldSchema.

Structs

ArrowRecordBatch
Arrow RecordBatch.
ArrowSchema
Arrow schema as specified in https://arrow.apache.org/docs/python/api/datatypes.html and serialized to bytes using IPC: https://arrow.apache.org/docs/format/Columnar.html#serialization-and-interprocess-communication-ipc
BatchCommitWriteStreamsResponse
Response message for BatchCommitWriteStreams.
FinalizeWriteStreamResponse
Response message for FinalizeWriteStream.
FlushRowsResponse
Respond message for FlushRows.
RowError
The message that presents row level error info in a request.
StorageError
Structured custom BigQuery Storage error message. The error can be attached as error details in the returned rpc Status. In particular, the use of error codes allows more structured error handling, and reduces the need to evaluate unstructured error text strings.
TableFieldSchema
TableFieldSchema defines a single field/column within a table schema.
TableSchema
Schema of a table. This schema is a subset of google.cloud.bigquery.v2.TableSchema containing information necessary to generate valid message to write to BigQuery.