The messages and enums that are part of this client library
Modules
- row_
error - Defines additional types related to RowError.
- storage_
error - Defines additional types related to StorageError.
- table_
field_ schema - Defines additional types related to TableFieldSchema.
Structs
- Arrow
Record Batch - Arrow RecordBatch.
- Arrow
Schema - Arrow schema as specified in https://arrow.apache.org/docs/python/api/datatypes.html and serialized to bytes using IPC: https://arrow.apache.org/docs/format/Columnar.html#serialization-and-interprocess-communication-ipc
- Batch
Commit Write Streams Response - Response message for
BatchCommitWriteStreams. - Finalize
Write Stream Response - Response message for
FinalizeWriteStream. - Flush
Rows Response - Respond message for
FlushRows. - RowError
- The message that presents row level error info in a request.
- Storage
Error - Structured custom BigQuery Storage error message. The error can be attached as error details in the returned rpc Status. In particular, the use of error codes allows more structured error handling, and reduces the need to evaluate unstructured error text strings.
- Table
Field Schema - TableFieldSchema defines a single field/column within a table schema.
- Table
Schema - Schema of a table. This schema is a subset of google.cloud.bigquery.v2.TableSchema containing information necessary to generate valid message to write to BigQuery.