Defines additional types related to AppendRowsRequest.
Structs
- Arrow
Data - Arrow schema and data.
- Proto
Data - ProtoData contains the data rows and schema when constructing append requests.
Enums
- Missing
Value Interpretation - An enum to indicate how to interpret missing values of fields that are present in user schema but missing in rows. A missing value can represent a NULL or a column default value defined in BigQuery table schema.
- Rows
- Input rows. The
writer_schemafield must be specified at the initial request and currently, it will be ignored if specified in following requests. Following requests must have data in the same format as the initial request.