Rows

#[non_exhaustive]
pub enum Rows { ProtoRows(Box<ProtoData>), ArrowRows(Box<ArrowData>), }
Input rows. The writer_schema field must be specified at the initial request and currently, it will be ignored if specified in following requests. Following requests must have data in the same format as the initial request.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ProtoRows(Box<ProtoData>)

Rows in proto format.



ArrowRows(Box<ArrowData>)

Rows in arrow format.

Implementations

Source

impl Rows

pub fn from_proto_rows(value: impl Into<Box<ProtoData>>) -> Self

Initializes the enum to the ProtoRows branch.

pub fn from_arrow_rows(value: impl Into<Box<ArrowData>>) -> Self

Initializes the enum to the ArrowRows branch.