#[non_exhaustive]pub enum Response {
AppendResult(Box<AppendResult>),
Error(Box<Status>),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AppendResult(Box<AppendResult>)
Result if the append is successful.
Error(Box<Status>)
Error returned when problems were encountered. If present, it indicates rows were not accepted into the system. Users can retry or continue with other append requests within the same connection.
Additional information about error signalling:
ALREADY_EXISTS: Happens when an append specified an offset, and the backend already has received data at this offset. Typically encountered in retry scenarios, and can be ignored.
OUT_OF_RANGE: Returned when the specified offset in the stream is beyond the current end of the stream.
INVALID_ARGUMENT: Indicates a malformed request or data.
ABORTED: Request processing is aborted because of prior failures. The request can be retried if previous failure is addressed.
INTERNAL: Indicates server side error(s) that can be retried.
Implementations
Sourceimpl Response
impl Response
Sourcepub fn from_append_result(value: impl Into<Box<AppendResult>>) -> Self
pub fn from_append_result(value: impl Into<Box<AppendResult>>) -> Self
Initializes the enum to the AppendResult branch.