#[non_exhaustive]pub struct ReadRowsResponse {
pub row_count: i64,
pub stats: Option<StreamStats>,
pub throttle_state: Option<ThrottleState>,
pub uncompressed_byte_size: Option<i64>,
pub total_estimated_row_count: Option<i64>,
pub rows: Option<Rows>,
pub schema: Option<Schema>,
/* private fields */
}Expand description
Response from calling ReadRows may include row data, progress and
throttling information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.row_count: i64Number of serialized rows in the rows block.
stats: Option<StreamStats>Statistics for the stream.
throttle_state: Option<ThrottleState>Throttling state. If unset, the latest response still describes the current throttling status.
uncompressed_byte_size: Option<i64>Optional. If the row data in this ReadRowsResponse is compressed, then uncompressed byte size is the original size of the uncompressed row data. If it is set to a value greater than 0, then decompress into a buffer of size uncompressed_byte_size using the compression codec that was requested during session creation time and which is specified in TableReadOptions.response_compression_codec in ReadSession. This value is not set if no response_compression_codec was not requested and it is -1 if the requested compression would not have reduced the size of this ReadRowsResponse’s row data. This attempts to match Apache Arrow’s behavior described here https://github.com/apache/arrow/issues/15102 where the uncompressed length may be set to -1 to indicate that the data that follows is not compressed, which can be useful for cases where compression does not yield appreciable savings. When uncompressed_byte_size is not greater than 0, the client should skip decompression.
total_estimated_row_count: Option<i64>Output only. The total estimated number of rows in the query results. Only populated when reading data from a BigQuery job.
This feature is not yet available.
rows: Option<Rows>Row data is returned in format specified during session creation.
schema: Option<Schema>The schema for the read. If read_options.selected_fields is set, the schema may be different from the table schema as it will only contain the selected fields. This schema is equivalent to the one returned by CreateSession. This field is only populated in the first ReadRowsResponse RPC.
Implementations
Sourceimpl ReadRowsResponse
impl ReadRowsResponse
Sourcepub fn set_row_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_row_count<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_stats<T>(self, v: T) -> Selfwhere
T: Into<StreamStats>,
pub fn set_stats<T>(self, v: T) -> Selfwhere
T: Into<StreamStats>,
Sourcepub fn set_or_clear_stats<T>(self, v: Option<T>) -> Selfwhere
T: Into<StreamStats>,
pub fn set_or_clear_stats<T>(self, v: Option<T>) -> Selfwhere
T: Into<StreamStats>,
Sourcepub fn set_throttle_state<T>(self, v: T) -> Selfwhere
T: Into<ThrottleState>,
pub fn set_throttle_state<T>(self, v: T) -> Selfwhere
T: Into<ThrottleState>,
Sets the value of throttle_state.
Example
use google_cloud_bigquery::model::ThrottleState;
let x = ReadRowsResponse::new().set_throttle_state(ThrottleState::default()/* use setters */);Sourcepub fn set_or_clear_throttle_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<ThrottleState>,
pub fn set_or_clear_throttle_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<ThrottleState>,
Sets or clears the value of throttle_state.
Example
use google_cloud_bigquery::model::ThrottleState;
let x = ReadRowsResponse::new().set_or_clear_throttle_state(Some(ThrottleState::default()/* use setters */));
let x = ReadRowsResponse::new().set_or_clear_throttle_state(None::<ThrottleState>);Sourcepub fn set_uncompressed_byte_size<T>(self, v: T) -> Self
pub fn set_uncompressed_byte_size<T>(self, v: T) -> Self
Sets the value of uncompressed_byte_size.
Example
let x = ReadRowsResponse::new().set_uncompressed_byte_size(42);Sourcepub fn set_or_clear_uncompressed_byte_size<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_uncompressed_byte_size<T>(self, v: Option<T>) -> Self
Sets or clears the value of uncompressed_byte_size.
Example
let x = ReadRowsResponse::new().set_or_clear_uncompressed_byte_size(Some(42));
let x = ReadRowsResponse::new().set_or_clear_uncompressed_byte_size(None::<i32>);Sourcepub fn set_total_estimated_row_count<T>(self, v: T) -> Self
pub fn set_total_estimated_row_count<T>(self, v: T) -> Self
Sets the value of total_estimated_row_count.
Example
let x = ReadRowsResponse::new().set_total_estimated_row_count(42);Sourcepub fn set_or_clear_total_estimated_row_count<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_total_estimated_row_count<T>(self, v: Option<T>) -> Self
Sets or clears the value of total_estimated_row_count.
Example
let x = ReadRowsResponse::new().set_or_clear_total_estimated_row_count(Some(42));
let x = ReadRowsResponse::new().set_or_clear_total_estimated_row_count(None::<i32>);Sourcepub fn avro_rows(&self) -> Option<&Box<AvroRows>>
pub fn avro_rows(&self) -> Option<&Box<AvroRows>>
The value of rows
if it holds a AvroRows, None if the field is not set or
holds a different branch.
Sourcepub fn set_avro_rows<T: Into<Box<AvroRows>>>(self, v: T) -> Self
pub fn set_avro_rows<T: Into<Box<AvroRows>>>(self, v: T) -> Self
Sets the value of rows
to hold a AvroRows.
Note that all the setters affecting rows are
mutually exclusive.
Example
use google_cloud_bigquery::model::AvroRows;
let x = ReadRowsResponse::new().set_avro_rows(AvroRows::default()/* use setters */);
assert!(x.avro_rows().is_some());
assert!(x.arrow_record_batch().is_none());Sourcepub fn arrow_record_batch(&self) -> Option<&Box<ArrowRecordBatch>>
pub fn arrow_record_batch(&self) -> Option<&Box<ArrowRecordBatch>>
The value of rows
if it holds a ArrowRecordBatch, None if the field is not set or
holds a different branch.
Sourcepub fn set_arrow_record_batch<T: Into<Box<ArrowRecordBatch>>>(
self,
v: T,
) -> Self
pub fn set_arrow_record_batch<T: Into<Box<ArrowRecordBatch>>>( self, v: T, ) -> Self
Sets the value of rows
to hold a ArrowRecordBatch.
Note that all the setters affecting rows are
mutually exclusive.
Example
use google_cloud_bigquery::model::ArrowRecordBatch;
let x = ReadRowsResponse::new().set_arrow_record_batch(ArrowRecordBatch::default()/* use setters */);
assert!(x.arrow_record_batch().is_some());
assert!(x.avro_rows().is_none());Sourcepub fn set_schema<T: Into<Option<Schema>>>(self, v: T) -> Self
pub fn set_schema<T: Into<Option<Schema>>>(self, v: T) -> Self
Sourcepub fn avro_schema(&self) -> Option<&Box<AvroSchema>>
pub fn avro_schema(&self) -> Option<&Box<AvroSchema>>
The value of schema
if it holds a AvroSchema, None if the field is not set or
holds a different branch.
Sourcepub fn set_avro_schema<T: Into<Box<AvroSchema>>>(self, v: T) -> Self
pub fn set_avro_schema<T: Into<Box<AvroSchema>>>(self, v: T) -> Self
Sets the value of schema
to hold a AvroSchema.
Note that all the setters affecting schema are
mutually exclusive.
Example
use google_cloud_bigquery::model::AvroSchema;
let x = ReadRowsResponse::new().set_avro_schema(AvroSchema::default()/* use setters */);
assert!(x.avro_schema().is_some());
assert!(x.arrow_schema().is_none());Sourcepub fn arrow_schema(&self) -> Option<&Box<ArrowSchema>>
pub fn arrow_schema(&self) -> Option<&Box<ArrowSchema>>
The value of schema
if it holds a ArrowSchema, None if the field is not set or
holds a different branch.
Sourcepub fn set_arrow_schema<T: Into<Box<ArrowSchema>>>(self, v: T) -> Self
pub fn set_arrow_schema<T: Into<Box<ArrowSchema>>>(self, v: T) -> Self
Sets the value of schema
to hold a ArrowSchema.
Note that all the setters affecting schema are
mutually exclusive.
Example
use google_cloud_bigquery::model::ArrowSchema;
let x = ReadRowsResponse::new().set_arrow_schema(ArrowSchema::default()/* use setters */);
assert!(x.arrow_schema().is_some());
assert!(x.avro_schema().is_none());Trait Implementations
Sourceimpl Clone for ReadRowsResponse
impl Clone for ReadRowsResponse
Sourceimpl Debug for ReadRowsResponse
impl Debug for ReadRowsResponse
Sourceimpl Default for ReadRowsResponse
impl Default for ReadRowsResponse
Sourceimpl Message for ReadRowsResponse
impl Message for ReadRowsResponse
Sourceimpl PartialEq for ReadRowsResponse
impl PartialEq for ReadRowsResponse
impl StructuralPartialEq for ReadRowsResponse