#[non_exhaustive]pub struct StorageError {
pub code: StorageErrorCode,
pub entity: String,
pub error_message: String,
/* private fields */
}Expand description
Structured custom BigQuery Storage error message. The error can be attached as error details in the returned rpc Status. In particular, the use of error codes allows more structured error handling, and reduces the need to evaluate unstructured error text strings.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code: StorageErrorCodeBigQuery Storage specific error code.
entity: StringName of the failed entity.
error_message: StringMessage that describes the error.
Implementations
Sourceimpl StorageError
impl StorageError
Sourcepub fn set_code<T: Into<StorageErrorCode>>(self, v: T) -> Self
pub fn set_code<T: Into<StorageErrorCode>>(self, v: T) -> Self
Sets the value of code.
Sourcepub fn set_entity<T: Into<String>>(self, v: T) -> Self
pub fn set_entity<T: Into<String>>(self, v: T) -> Self
Sets the value of entity.
Sourcepub fn set_error_message<T: Into<String>>(self, v: T) -> Self
pub fn set_error_message<T: Into<String>>(self, v: T) -> Self
Sets the value of error_message.