Extends crate::model.
Note that there is no real distinction between the types in model and
model_ext. The two modules are separate for library maintenance reasons.
Structs
- Append
Response - The return type of an
append()operation. - Complete
Query Metadata - Query
Metadata - Query
Request