#[non_exhaustive]pub struct AppendResponse {
pub offset: Option<i64>,
pub updated_schema: Option<TableSchema>,
}Expand description
The return type of an append() operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.offset: Option<i64>The row offset at which the last append occurred. The offset will not be set if appending using default streams.
updated_schema: Option<TableSchema>If set, the service reports that the table schema has changed.
Note that this notification is best effort. Changing a table schema can take several minutes to propagate on the server side.
The client library does not use this information to modify any internal state. It only forwards the notification to the application, which should react accordingly (if necessary).