#[non_exhaustive]pub struct QueryMetadata {Show 30 fields
pub cache_hit: Option<BoolValue>,
pub configuration: Option<JobConfiguration>,
pub creation_time: Option<i64>,
pub dml_stats: Option<DmlStats>,
pub end_time: Option<i64>,
pub errors: Vec<ErrorProto>,
pub etag: String,
pub id: String,
pub job_complete: Option<BoolValue>,
pub job_creation_reason: Option<JobCreationReason>,
pub job_reference: Option<JobReference>,
pub kind: String,
pub location: String,
pub num_dml_affected_rows: Option<Int64Value>,
pub page_row_count: i64,
pub page_token: String,
pub principal_subject: String,
pub query_id: String,
pub schema: Option<TableSchema>,
pub self_link: String,
pub session_info: Option<SessionInfo>,
pub start_time: Option<i64>,
pub statement_type: String,
pub statistics: Option<JobStatistics>,
pub status: Option<JobStatus>,
pub total_bytes_billed: Option<i64>,
pub total_bytes_processed: Option<Int64Value>,
pub total_rows: Option<UInt64Value>,
pub total_slot_ms: Option<i64>,
pub user_email: String,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cache_hit: Option<BoolValue>Whether the query result was fetched from the query cache.
configuration: Option<JobConfiguration>Required. Describes the job configuration.
creation_time: Option<i64>Output only. Creation time of this query, in milliseconds since the epoch. This field will be present on all queries.
dml_stats: Option<DmlStats>Output only. Detailed statistics for DML statements INSERT, UPDATE, DELETE, MERGE or TRUNCATE.
end_time: Option<i64>Output only. End time of this query, in milliseconds since the epoch. This field will be present whenever a query job is in the DONE state.
errors: Vec<ErrorProto>Output only. The first errors or warnings encountered during the running of the job. The final message includes the number of errors that caused the process to stop. Errors here do not necessarily mean that the job has completed or was unsuccessful. For more information about error messages, see Error messages.
etag: StringOutput only. A hash of this resource.
id: StringOutput only. Opaque ID field of the job.
job_complete: Option<BoolValue>Whether the query has completed or not. If rows or totalRows are present, this will always be true. If this is false, totalRows will not be available.
job_creation_reason: Option<JobCreationReason>Output only. The reason why a Job was created.
job_reference: Option<JobReference>Optional. Reference describing the unique-per-user name of the job.
kind: StringOutput only. The type of the resource.
location: StringOutput only. The geographic location of the query.
For more information about BigQuery locations, see: https://cloud.google.com/bigquery/docs/locations
num_dml_affected_rows: Option<Int64Value>Output only. The number of rows affected by a DML statement. Present only for DML statements INSERT, UPDATE or DELETE.
page_row_count: i64Output only. The number of rows out of total_rows returned in this
response.
This feature is not yet available.
page_token: StringA token used for paging results. A non-empty token indicates that
additional results are available. To see additional results,
query the
jobs.getQueryResults
method. For more information, see Paging through table
data.
principal_subject: StringOutput only. [Full-projection-only] String representation of identity of requesting party. Populated for both first- and third-party identities. Only present for APIs that support third-party identities.
query_id: StringAuto-generated ID for the query.
schema: Option<TableSchema>The schema of the results. Present only when the query completes successfully.
self_link: StringOutput only. A URL that can be used to access the resource again.
session_info: Option<SessionInfo>Output only. Information of the session if this job is part of one.
start_time: Option<i64>Output only. Start time of this query, in milliseconds since the epoch. This field will be present when the query job transitions from the PENDING state to either RUNNING or DONE.
statement_type: StringOutput only. The type of query statement, if valid. Possible values:
SELECT:SELECTstatement.ASSERT:ASSERTstatement.INSERT:INSERTstatement.UPDATE:UPDATEstatement.DELETE:DELETEstatement.MERGE:MERGEstatement.CREATE_TABLE:CREATE TABLEstatement, withoutAS SELECT.CREATE_TABLE_AS_SELECT:CREATE TABLE AS SELECTstatement.CREATE_VIEW:CREATE VIEWstatement.CREATE_MODEL:CREATE MODELstatement.CREATE_MATERIALIZED_VIEW:CREATE MATERIALIZED VIEWstatement.CREATE_FUNCTION:CREATE FUNCTIONstatement.CREATE_TABLE_FUNCTION:CREATE TABLE FUNCTIONstatement.CREATE_PROCEDURE:CREATE PROCEDUREstatement.CREATE_ROW_ACCESS_POLICY:CREATE ROW ACCESS POLICYstatement.CREATE_SCHEMA:CREATE SCHEMAstatement.CREATE_SNAPSHOT_TABLE:CREATE SNAPSHOT TABLEstatement.CREATE_SEARCH_INDEX:CREATE SEARCH INDEXstatement.DROP_TABLE:DROP TABLEstatement.DROP_EXTERNAL_TABLE:DROP EXTERNAL TABLEstatement.DROP_VIEW:DROP VIEWstatement.DROP_MODEL:DROP MODELstatement.DROP_MATERIALIZED_VIEW:DROP MATERIALIZED VIEWstatement.DROP_FUNCTION:DROP FUNCTIONstatement.DROP_TABLE_FUNCTION:DROP TABLE FUNCTIONstatement.DROP_PROCEDURE:DROP PROCEDUREstatement.DROP_SEARCH_INDEX:DROP SEARCH INDEXstatement.DROP_SCHEMA:DROP SCHEMAstatement.DROP_SNAPSHOT_TABLE:DROP SNAPSHOT TABLEstatement.DROP_ROW_ACCESS_POLICY:DROP [ALL] ROW ACCESS POLICY|POLICIESstatement.ALTER_TABLE:ALTER TABLEstatement.ALTER_VIEW:ALTER VIEWstatement.ALTER_MATERIALIZED_VIEW:ALTER MATERIALIZED VIEWstatement.ALTER_SCHEMA:ALTER SCHEMAstatement.SCRIPT:SCRIPT.TRUNCATE_TABLE:TRUNCATE TABLEstatement.CREATE_EXTERNAL_TABLE:CREATE EXTERNAL TABLEstatement.EXPORT_DATA:EXPORT DATAstatement.EXPORT_MODEL:EXPORT MODELstatement.LOAD_DATA:LOAD DATAstatement.CALL:CALLstatement.
statistics: Option<JobStatistics>Output only. Information about the job, including starting time and ending time of the job.
status: Option<JobStatus>Output only. The status of this job. Examine this value when polling an asynchronous job to see if the job is complete.
total_bytes_billed: Option<i64>Output only. If the project is configured to use on-demand pricing, then this field contains the total bytes billed for the job. If the project is configured to use flat-rate pricing, then you are not billed for bytes and this field is informational only.
total_bytes_processed: Option<Int64Value>The total number of bytes processed for this query. If this query was a dry run, this is the number of bytes that would be processed if the query were run.
total_rows: Option<UInt64Value>The total number of rows in the complete query result set, which can be more than the number of rows in this single page of results.
total_slot_ms: Option<i64>Output only. Number of slot ms the user is actually billed for.
user_email: StringOutput only. Email address of the user who ran the job.
Implementations
Sourceimpl QueryMetadata
impl QueryMetadata
Sourcepub fn set_cache_hit<T>(self, v: T) -> Self
pub fn set_cache_hit<T>(self, v: T) -> Self
Sets the value of cache_hit.
Sourcepub fn set_or_clear_cache_hit<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_cache_hit<T>(self, v: Option<T>) -> Self
Sets or clears the value of cache_hit.
Sourcepub fn set_configuration<T>(self, v: T) -> Selfwhere
T: Into<JobConfiguration>,
pub fn set_configuration<T>(self, v: T) -> Selfwhere
T: Into<JobConfiguration>,
Sets the value of configuration.
Sourcepub fn set_or_clear_configuration<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobConfiguration>,
pub fn set_or_clear_configuration<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobConfiguration>,
Sets or clears the value of configuration.
Sourcepub fn set_creation_time<T>(self, v: T) -> Self
pub fn set_creation_time<T>(self, v: T) -> Self
Sets the value of creation_time.
Sourcepub fn set_or_clear_creation_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creation_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of creation_time.
Sourcepub fn set_dml_stats<T>(self, v: T) -> Self
pub fn set_dml_stats<T>(self, v: T) -> Self
Sets the value of dml_stats.
Sourcepub fn set_or_clear_dml_stats<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_dml_stats<T>(self, v: Option<T>) -> Self
Sets or clears the value of dml_stats.
Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sets the value of end_time.
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of end_time.
Sourcepub fn set_errors<T, V>(self, v: T) -> Self
pub fn set_errors<T, V>(self, v: T) -> Self
Sets the value of errors.
Sourcepub fn set_job_complete<T>(self, v: T) -> Self
pub fn set_job_complete<T>(self, v: T) -> Self
Sets the value of job_complete.
Sourcepub fn set_or_clear_job_complete<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_job_complete<T>(self, v: Option<T>) -> Self
Sets or clears the value of job_complete.
Sourcepub fn set_job_creation_reason<T>(self, v: T) -> Selfwhere
T: Into<JobCreationReason>,
pub fn set_job_creation_reason<T>(self, v: T) -> Selfwhere
T: Into<JobCreationReason>,
Sets the value of job_creation_reason.
Sourcepub fn set_or_clear_job_creation_reason<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobCreationReason>,
pub fn set_or_clear_job_creation_reason<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobCreationReason>,
Sets or clears the value of job_creation_reason.
Sourcepub fn set_job_reference<T>(self, v: T) -> Selfwhere
T: Into<JobReference>,
pub fn set_job_reference<T>(self, v: T) -> Selfwhere
T: Into<JobReference>,
Sets the value of job_reference.
Sourcepub fn set_or_clear_job_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobReference>,
pub fn set_or_clear_job_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobReference>,
Sets or clears the value of job_reference.
Sourcepub fn set_location<T: Into<String>>(self, v: T) -> Self
pub fn set_location<T: Into<String>>(self, v: T) -> Self
Sets the value of location.
Sourcepub fn set_num_dml_affected_rows<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_num_dml_affected_rows<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of num_dml_affected_rows.
Sourcepub fn set_or_clear_num_dml_affected_rows<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_num_dml_affected_rows<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of num_dml_affected_rows.
Sourcepub fn set_page_row_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_page_row_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of page_row_count.
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Sourcepub fn set_principal_subject<T: Into<String>>(self, v: T) -> Self
pub fn set_principal_subject<T: Into<String>>(self, v: T) -> Self
Sets the value of principal_subject.
Sourcepub fn set_query_id<T: Into<String>>(self, v: T) -> Self
pub fn set_query_id<T: Into<String>>(self, v: T) -> Self
Sets the value of query_id.
Sourcepub fn set_schema<T>(self, v: T) -> Selfwhere
T: Into<TableSchema>,
pub fn set_schema<T>(self, v: T) -> Selfwhere
T: Into<TableSchema>,
Sets the value of schema.
Sourcepub fn set_or_clear_schema<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableSchema>,
pub fn set_or_clear_schema<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableSchema>,
Sets or clears the value of schema.
Sourcepub fn set_self_link<T: Into<String>>(self, v: T) -> Self
pub fn set_self_link<T: Into<String>>(self, v: T) -> Self
Sets the value of self_link.
Sourcepub fn set_session_info<T>(self, v: T) -> Selfwhere
T: Into<SessionInfo>,
pub fn set_session_info<T>(self, v: T) -> Selfwhere
T: Into<SessionInfo>,
Sets the value of session_info.
Sourcepub fn set_or_clear_session_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<SessionInfo>,
pub fn set_or_clear_session_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<SessionInfo>,
Sets or clears the value of session_info.
Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Sourcepub fn set_statement_type<T: Into<String>>(self, v: T) -> Self
pub fn set_statement_type<T: Into<String>>(self, v: T) -> Self
Sets the value of statement_type.
Sourcepub fn set_statistics<T>(self, v: T) -> Selfwhere
T: Into<JobStatistics>,
pub fn set_statistics<T>(self, v: T) -> Selfwhere
T: Into<JobStatistics>,
Sets the value of statistics.
Sourcepub fn set_or_clear_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobStatistics>,
pub fn set_or_clear_statistics<T>(self, v: Option<T>) -> Selfwhere
T: Into<JobStatistics>,
Sets or clears the value of statistics.
Sourcepub fn set_status<T>(self, v: T) -> Self
pub fn set_status<T>(self, v: T) -> Self
Sets the value of status.
Sourcepub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
Sets or clears the value of status.
Sourcepub fn set_total_bytes_billed<T>(self, v: T) -> Self
pub fn set_total_bytes_billed<T>(self, v: T) -> Self
Sets the value of total_bytes_billed.
Sourcepub fn set_or_clear_total_bytes_billed<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_total_bytes_billed<T>(self, v: Option<T>) -> Self
Sets or clears the value of total_bytes_billed.
Sourcepub fn set_total_bytes_processed<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_total_bytes_processed<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of total_bytes_processed.
Sourcepub fn set_or_clear_total_bytes_processed<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_total_bytes_processed<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of total_bytes_processed.
Sourcepub fn set_total_rows<T>(self, v: T) -> Selfwhere
T: Into<UInt64Value>,
pub fn set_total_rows<T>(self, v: T) -> Selfwhere
T: Into<UInt64Value>,
Sets the value of total_rows.
Sourcepub fn set_or_clear_total_rows<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt64Value>,
pub fn set_or_clear_total_rows<T>(self, v: Option<T>) -> Selfwhere
T: Into<UInt64Value>,
Sets or clears the value of total_rows.
Sourcepub fn set_total_slot_ms<T>(self, v: T) -> Self
pub fn set_total_slot_ms<T>(self, v: T) -> Self
Sets the value of total_slot_ms.
Sourcepub fn set_or_clear_total_slot_ms<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_total_slot_ms<T>(self, v: Option<T>) -> Self
Sets or clears the value of total_slot_ms.
Sourcepub fn set_user_email<T: Into<String>>(self, v: T) -> Self
pub fn set_user_email<T: Into<String>>(self, v: T) -> Self
Sets the value of user_email.