Types related to querying with a BigQuery client.
Modules
- retry_
policy - Defines a retry policy for BigQuery.
Structs
- Complete
Query - A handle representing a successfully completed query ready for reading results.
- Query
- A handle representing a running or completed SQL query execution.
- Row
- A container for a single row within a query result set.
- RowIterator
- An iterator over rows returned by a query.
- SqlValue
- An opaque representation of a BigQuery SQL cell value.
Traits
- Column
Index - A trait for types that can be used to index into a
RoworSqlValue. - FromSql
- A trait for converting BigQuery value representations into Rust types.