pub struct CompleteQuery { /* private fields */ }Expand description
A handle representing a successfully completed query ready for reading results.
Query::until_done() returns a CompleteQuery.
This handle provides access to cached execution metadata, schema
definitions, and a row iterator via read().
Example
let complete = client
.query("SELECT 'done' AS status")
.until_done()
.await?;
println!("Cache hit: {:?}", complete.metadata().cache_hit);Implementations
Sourceimpl CompleteQuery
impl CompleteQuery
Sourcepub fn read(self) -> RowIterator
pub fn read(self) -> RowIterator
Read the result set of the query.
Example
let mut rows = client
.query("SELECT 100 AS score")
.until_done()
.await?
.read();
while let Some(row) = rows.next().await.transpose()? {
let score: i64 = row.get("score");
println!("Score: {score}");
}Sourcepub fn metadata(&self) -> &CompleteQueryMetadata
pub fn metadata(&self) -> &CompleteQueryMetadata
Returns a reference to the cached summary metadata for this query.
The returned CompleteQueryMetadata contains
summary statistics such as total rows, schema details, cache hit
indicators, and estimated bytes processed without making additional
RPCs.
Example
let completed = client
.query("SELECT 'metadata_check'")
.until_done()
.await?;
let meta = completed.metadata();
println!("Total rows: {:?}", meta.total_rows);Sourcepub fn get_job(&self) -> Option<GetJob>
pub fn get_job(&self) -> Option<GetJob>
Build a request to fetch full Job execution metadata from the service for this query.
Returns
Noneif the query was executed without creating a job (for example, when usingJobCreationMode::JobCreationOptional, or when the query was a dry run).
Example
let completed = client
.query("SELECT 1")
.set_job_creation_mode(JobCreationMode::JobCreationRequired) // Forces a job to be created
.until_done()
.await?;
match completed.get_job() {
Some(req) => {
let job_info = req.send().await?;
println!("Executed by user: {}", job_info.user_email);
}
None => {
println!(
"Query was run without creating a job. Query ID: {}",
completed.metadata().query_id
);
}
}Trait Implementations
Sourceimpl Clone for CompleteQuery
impl Clone for CompleteQuery
Sourcefn clone(&self) -> CompleteQuery
fn clone(&self) -> CompleteQuery
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for CompleteQuery
impl !UnwindSafe for CompleteQuery
impl Freeze for CompleteQuery
impl Send for CompleteQuery
impl Sync for CompleteQuery
impl Unpin for CompleteQuery
impl UnsafeUnpin for CompleteQuery